diff graal/com.oracle.truffle.api/src/com/oracle/truffle/api/tools/CoverageTracker.java @ 19186:3d2296dbace9

Truffle/Instrumentation: TruffleTool renamed to InstrumentationTool (the base class for a group of tools that collect information during program execution)
author Michael Van De Vanter <michael.van.de.vanter@oracle.com>
date Sun, 08 Feb 2015 20:05:40 -0800
parents ac114ad31cdd
children c5b20395a8bf
line wrap: on
line diff
--- a/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/tools/CoverageTracker.java	Sat Feb 07 02:47:00 2015 +0100
+++ b/graal/com.oracle.truffle.api/src/com/oracle/truffle/api/tools/CoverageTracker.java	Sun Feb 08 20:05:40 2015 -0800
@@ -38,7 +38,7 @@
 import com.oracle.truffle.api.source.*;
 
 /**
  * A {@link TruffleTool} that counts interpreter <em>execution calls</em> to AST nodes that hold a
  * specified {@linkplain SyntaxTag tag}, tabulated by source and line number associated with each
  * node. Tags are presumed to be applied external to the tool. If no tag is specified,
  * {@linkplain StandardSyntaxTag#STATEMENT STATEMENT} is used, corresponding to conventional
@@ -46,7 +46,7 @@
  * <p>
  * <b>Tool Life Cycle</b>
  * <p>
  * See {@link TruffleTool} for the life cycle common to all such tools.
  * <p>
  * <b>Execution Counts</b>
  * <p>
@@ -72,7 +72,7 @@
  * @see Instrument
  * @see SyntaxTag
  */
-public final class CoverageTracker extends TruffleTool {
+public final class CoverageTracker extends InstrumentationTool {
 
     /** Counting data. */
     private final Map<LineLocation, CoverageCounter> counters = new HashMap<>();
@@ -38,7 +38,7 @@
 
 /**
- * A {@link TruffleTool} that counts interpreter <em>execution calls</em> to AST nodes that hold a
+ * A {@link InstrumentationTool} that counts interpreter <em>execution calls</em> to AST nodes that hold a
  * specified {@linkplain SyntaxTag tag}, tabulated by source and line number associated with each
  * node. Tags are presumed to be applied external to the tool. If no tag is specified,
@@ -46,7 +46,7 @@
  * <b>Tool Life Cycle</b>
  * <p>
- * See {@link TruffleTool} for the life cycle common to all such tools.
+ * See {@link InstrumentationTool} for the life cycle common to all such tools.
  * <p>
  * <b>Execution Counts</b>